@@ -1,5 +1,8 @@
 var NAVTREEINDEX50 =
 {
+"eye__sink__f__pydoc__template_8h.html#a858c20f6e302a4eb093eed6dc1681427":[6,0,29,2,0,0,0,6,6],
+"eye__sink__f__pydoc__template_8h.html#a87872555d73f1b723bb5e00c0d343011":[6,0,29,2,0,0,0,6,3],
+"eye__sink__f__pydoc__template_8h.html#a8a2aecf5d16ba0bdddd89ff70ebfb785":[6,0,29,2,0,0,0,6,4],
 "eye__sink__f__pydoc__template_8h.html#a9196628537ada4d5673b0a656f776c1c":[6,0,29,2,0,0,0,6,34],
 "eye__sink__f__pydoc__template_8h.html#a93be6adbdcaf20dec592a7794e432138":[6,0,29,2,0,0,0,6,11],
 "eye__sink__f__pydoc__template_8h.html#a9636b22102f80ab1517fb58bb1c549d1":[6,0,29,2,0,0,0,6,12],
@@ -246,8 +249,5 @@ var NAVTREEINDEX50 =
 "filterbank__pydoc__template_8h.html#aa464e22ade6e75429e8c18dd3ea3bb8e":[6,0,21,2,0,0,0,7,3],
 "filterbank__pydoc__template_8h.html#ad92476b1fe57d835449cab6993f0f7a4":[6,0,21,2,0,0,0,7,6],
 "filterbank__pydoc__template_8h.html#ae055966af494127465de97f7146fed32":[6,0,21,2,0,0,0,7,1],
-"filterbank__pydoc__template_8h_source.html":[6,0,21,2,0,0,0,7],
-"filterbank__vcvcf_8h.html":[6,0,21,1,0,0,9],
-"filterbank__vcvcf_8h_source.html":[6,0,21,1,0,0,9],
-"filterbank__vcvcf__pydoc__template_8h.html":[6,0,21,2,0,0,0,8]
+"filterbank__pydoc__template_8h_source.html":[6,0,21,2,0,0,0,7]
 };
