@@ -1,5 +1,8 @@
 var NAVTREEINDEX68 =
 {
+"pmt__pydoc__template_8h.html#a6d6e44a40181dcb4dbff82f480a80e27":[6,0,3,1,1,0,0,1,190],
+"pmt__pydoc__template_8h.html#a6d72f132d4911fad6aeadca1dfd3c8d9":[6,0,3,1,1,0,0,1,13],
+"pmt__pydoc__template_8h.html#a6e72b8bf726253c1f98525a89ada72fc":[6,0,3,1,1,0,0,1,250],
 "pmt__pydoc__template_8h.html#a6fb3e30c80c4f1e77e804713274ad7fb":[6,0,3,1,1,0,0,1,1],
 "pmt__pydoc__template_8h.html#a6fcc93e6b6af5fb2f1a1965b6e6c8058":[6,0,3,1,1,0,0,1,32],
 "pmt__pydoc__template_8h.html#a6fcd61f058d519c1702942dc8b52da31":[6,0,3,1,1,0,0,1,238],
@@ -246,8 +249,5 @@ var NAVTREEINDEX68 =
 "polar__decoder__common__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[6,0,17,2,0,0,0,25,0],
 "polar__decoder__common__pydoc__template_8h.html#a9f55ff6594bb45fe75d2a82bdabad109":[6,0,17,2,0,0,0,25,6],
 "polar__decoder__common__pydoc__template_8h.html#aad7e0d1e52140dc45c268318cadfcf26":[6,0,17,2,0,0,0,25,4],
-"polar__decoder__common__pydoc__template_8h.html#abeec6342fbf9a89841a8ecf0074b03db":[6,0,17,2,0,0,0,25,2],
-"polar__decoder__common__pydoc__template_8h_source.html":[6,0,17,2,0,0,0,25],
-"polar__decoder__sc_8h.html":[6,0,17,1,0,0,34],
-"polar__decoder__sc_8h_source.html":[6,0,17,1,0,0,34]
+"polar__decoder__common__pydoc__template_8h.html#abeec6342fbf9a89841a8ecf0074b03db":[6,0,17,2,0,0,0,25,2]
 };
