@@ -1,5 +1,8 @@
 var NAVTREEINDEX76 =
 {
+"tags__strobe__pydoc__template_8h.html#a4bfec3c39cb83a44e01a13d401dc4544":[6,0,9,2,0,0,0,130,7],
+"tags__strobe__pydoc__template_8h.html#a6634cbee37b95f1e925fe9d3a478add4":[6,0,9,2,0,0,0,130,3],
+"tags__strobe__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[6,0,9,2,0,0,0,130,0],
 "tags__strobe__pydoc__template_8h.html#a92dbdd45c3850b4e9ac26c914b8e498e":[6,0,9,2,0,0,0,130,8],
 "tags__strobe__pydoc__template_8h.html#aa68deb93941bfd5fd1cc5125fffdd799":[6,0,9,2,0,0,0,130,9],
 "tags__strobe__pydoc__template_8h.html#abf72f165763ac72f87dc368e05b399b2":[6,0,9,2,0,0,0,130,2],
@@ -246,8 +249,5 @@ var NAVTREEINDEX76 =
 "time__sink__f__pydoc__template_8h.html#a695529ac4d73e10b30e8a6cbc8bb81a3":[6,0,29,2,0,0,0,22,11],
 "time__sink__f__pydoc__template_8h.html#a6fd5e93e9985d5046b40ba39f5ec6b3f":[6,0,29,2,0,0,0,22,8],
 "time__sink__f__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[6,0,29,2,0,0,0,22,0],
-"time__sink__f__pydoc__template_8h.html#a820322626b841acdeb4ef77a689aeb94":[6,0,29,2,0,0,0,22,19],
-"time__sink__f__pydoc__template_8h.html#a8955a83687cf8114772f692df46ba3ec":[6,0,29,2,0,0,0,22,39],
-"time__sink__f__pydoc__template_8h.html#a8962c40e1f49db9b13bf7a830066126f":[6,0,29,2,0,0,0,22,7],
-"time__sink__f__pydoc__template_8h.html#a8b5de8dba81a3b6beb7a8daaa20fa4b4":[6,0,29,2,0,0,0,22,9]
+"time__sink__f__pydoc__template_8h.html#a820322626b841acdeb4ef77a689aeb94":[6,0,29,2,0,0,0,22,19]
 };
