@@ -1,5 +1,8 @@
 var NAVTREEINDEX77 =
 {
+"time__sink__f__pydoc__template_8h.html#a8955a83687cf8114772f692df46ba3ec":[6,0,29,2,0,0,0,22,39],
+"time__sink__f__pydoc__template_8h.html#a8962c40e1f49db9b13bf7a830066126f":[6,0,29,2,0,0,0,22,7],
+"time__sink__f__pydoc__template_8h.html#a8b5de8dba81a3b6beb7a8daaa20fa4b4":[6,0,29,2,0,0,0,22,9],
 "time__sink__f__pydoc__template_8h.html#a98a283f94ba6dba67cca10238d5ff084":[6,0,29,2,0,0,0,22,4],
 "time__sink__f__pydoc__template_8h.html#a98b8be3144bfd2510bc571a005a7867f":[6,0,29,2,0,0,0,22,32],
 "time__sink__f__pydoc__template_8h.html#aaa41bf7f1560e3b558668ffc22ef188b":[6,0,29,2,0,0,0,22,37],
@@ -246,8 +249,5 @@ var NAVTREEINDEX77 =
 "usrp__block__pydoc__template_8h.html#a4976a38c8afcd3b94aeebd3aeb4b098f":[6,0,34,2,0,0,0,14,62],
 "usrp__block__pydoc__template_8h.html#a4baf1f8fca6f0d929aa5e1d0619442ff":[6,0,34,2,0,0,0,14,37],
 "usrp__block__pydoc__template_8h.html#a4bc6a593116d1468338ab57d657cb042":[6,0,34,2,0,0,0,14,18],
-"usrp__block__pydoc__template_8h.html#a512b08282cf85a92bac2eb28c7e2d27b":[6,0,34,2,0,0,0,14,4],
-"usrp__block__pydoc__template_8h.html#a54333908d48c9b32dd4d9da4cf1d9c32":[6,0,34,2,0,0,0,14,76],
-"usrp__block__pydoc__template_8h.html#a5507c0de5429b704eb7e3c24523cb265":[6,0,34,2,0,0,0,14,70],
-"usrp__block__pydoc__template_8h.html#a59ee1a1c9e2a9073c1ba507d1a57a4dd":[6,0,34,2,0,0,0,14,17]
+"usrp__block__pydoc__template_8h.html#a512b08282cf85a92bac2eb28c7e2d27b":[6,0,34,2,0,0,0,14,4]
 };
