@@ -1,5 +1,8 @@
 var NAVTREEINDEX78 =
 {
+"usrp__block__pydoc__template_8h.html#a54333908d48c9b32dd4d9da4cf1d9c32":[6,0,34,2,0,0,0,14,76],
+"usrp__block__pydoc__template_8h.html#a5507c0de5429b704eb7e3c24523cb265":[6,0,34,2,0,0,0,14,70],
+"usrp__block__pydoc__template_8h.html#a59ee1a1c9e2a9073c1ba507d1a57a4dd":[6,0,34,2,0,0,0,14,17],
 "usrp__block__pydoc__template_8h.html#a5cb607392f4ffd3b0e7e3984aa84c6b3":[6,0,34,2,0,0,0,14,64],
 "usrp__block__pydoc__template_8h.html#a5eab3bbce4926051b6f600d579deefab":[6,0,34,2,0,0,0,14,11],
 "usrp__block__pydoc__template_8h.html#a6625060590050070a7fca9859f5d211a":[6,0,34,2,0,0,0,14,71],
@@ -246,8 +249,5 @@ var NAVTREEINDEX78 =
 "waterfall__sink__c__pydoc__template_8h.html#a70dce63c59ced3735bbadf8aecc44989":[6,0,29,2,0,0,0,29,6],
 "waterfall__sink__c__pydoc__template_8h.html#a72890fd7ff5dac433a296f8054749281":[6,0,29,2,0,0,0,29,13],
 "waterfall__sink__c__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[6,0,29,2,0,0,0,29,0],
-"waterfall__sink__c__pydoc__template_8h.html#a7698e7c62c6f1927b109852c9967ffec":[6,0,29,2,0,0,0,29,12],
-"waterfall__sink__c__pydoc__template_8h.html#a7c65bc82725601e2a49c69d42b3b673d":[6,0,29,2,0,0,0,29,18],
-"waterfall__sink__c__pydoc__template_8h.html#a7d277165ff26b1d8b542692617a76727":[6,0,29,2,0,0,0,29,17],
-"waterfall__sink__c__pydoc__template_8h.html#a7f567c39d1fc83d6ee571885e4ae330a":[6,0,29,2,0,0,0,29,26]
+"waterfall__sink__c__pydoc__template_8h.html#a7698e7c62c6f1927b109852c9967ffec":[6,0,29,2,0,0,0,29,12]
 };
